@@ -3,6 +3,7 @@ use strict;
 use GRID::Machine;
 use GRID::Machine::Group;
 use List::Util qw(sum);
+use Time::HiRes qw(time gettimeofday tv_interval);
 
 my @MACHINE_NAMES = split /\s+/, $ENV{MACHINES};
 my @m = map { GRID::Machine->new(host => $_, wait => 5, survive => 1) } @MACHINE_NAMES;
@@ -20,10 +21,13 @@ $c->sub(suma_areas => q{
    $sum /= $N; 
 });
 
-my ($N, $np, $pi)  = (1000, 4, 0);
+my ($N, $np, $pi)  = (1e7, 4, 0);
 
 my @args = map {  [$_, $N, $np] } 0..$np-1;
 
-print sum($c->suma_areas(args => \@args)->Results)."\n";
+my $t0 = [gettimeofday];
+$pi = sum($c->suma_areas(args => \@args)->Results);
+my $elapsed = tv_interval ($t0);
+print "Pi = $pi. N = $N Time = $elapsed\n";
 
 
